==> jc-1.4.0.tar.gz: polyglot/frontend/FileSource.h <==
// public class polyglot.frontend.FileSource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 39c133c176bc5fd1 polyglot_frontend_FileSource
// @dep_class cd88b669bec8f787 polyglot_frontend_Source

// header file dependencies
// @dep_header polyglot_frontend_Source

#include "polyglot/frontend/Source.h"

#ifndef _JC_polyglot_frontend_FileSource_H_
#define _JC_polyglot_frontend_FileSource_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_FileReader$object;
struct _jc_java_io_Reader$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_frontend_FileSource$sub_refs	_jc_polyglot_frontend_FileSource$sub_refs;
typedef struct _jc_polyglot_frontend_FileSource$sub_nonrefs	_jc_polyglot_frontend_FileSource$sub_nonrefs;
typedef struct _jc_polyglot_frontend_FileSource$refs	_jc_polyglot_frontend_FileSource$refs;
typedef struct _jc_polyglot_frontend_FileSource$nonrefs	_jc_polyglot_frontend_FileSource$nonrefs;
typedef struct _jc_polyglot_frontend_FileSource$object	_jc_polyglot_frontend_FileSource$object;

typedef const struct _jc_polyglot_frontend_FileSource$vmethods	_jc_polyglot_frontend_FileSource$vmethods;
typedef const struct _jc_polyglot_frontend_FileSource$vtable	_jc_polyglot_frontend_FileSource$vtable;
typedef const struct _jc_polyglot_frontend_FileSource$vtype	_jc_polyglot_frontend_FileSource$vtype;

// Constructors
extern void _jc_polyglot_frontend_FileSource$method$_init$538ee07130435a5e(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_java_io_File$object *);
extern void _jc_polyglot_frontend_FileSource$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_polyglot_frontend_FileSource$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *);
extern jboolean _jc_polyglot_frontend_FileSource$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_polyglot_frontend_FileSource$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *);
extern struct _jc_java_io_Reader$object *_jc_polyglot_frontend_FileSource$method$open$bf04e002098c1544(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_FileSource$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_FileSource$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_polyglot_frontend_FileSource$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_frontend_FileSource$method_info$hashCode$53152098849316df;
extern _jc_method _jc_polyglot_frontend_FileSource$method_info$open$bf04e002098c1544;
extern _jc_method _jc_polyglot_frontend_FileSource$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_frontend_FileSource$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *);
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *);
	struct _jc_java_io_Reader$object	*(*open$bf04e002098c1544)(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *);
};

// Vtable
struct _jc_polyglot_frontend_FileSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_Source$vmethods	polyglot_frontend_Source;
	_jc_polyglot_frontend_FileSource$vmethods	polyglot_frontend_FileSource;
};

// Vtype
struct _jc_polyglot_frontend_FileSource$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_FileSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_FileSource$sub_refs {
	struct _jc_java_io_File$object	*file;
	struct _jc_java_io_FileReader$object	*reader;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_FileSource$refs {
    _jc_polyglot_frontend_FileSource$sub_refs	polyglot_frontend_FileSource;
    _jc_polyglot_frontend_Source$sub_refs	polyglot_frontend_Source;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_FileSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_FileSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_Source$sub_nonrefs	polyglot_frontend_Source;
    _jc_polyglot_frontend_FileSource$sub_nonrefs	polyglot_frontend_FileSource;
};

// Object instance structure
struct _jc_polyglot_frontend_FileSource$object {
	_jc_polyglot_frontend_FileSource$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_FileSource$vtype	*vtype;
	_jc_polyglot_frontend_FileSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_FileSource$vtype _jc_polyglot_frontend_FileSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_FileSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_FileSource$class_object;

#endif	/* _JC_polyglot_frontend_FileSource_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/FileSource.h <==
// public class polyglot.frontend.FileSource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 39c133c176bc5fd1 polyglot_frontend_FileSource
// @dep_class cd88b669bec8f787 polyglot_frontend_Source

// header file dependencies
// @dep_header polyglot_frontend_Source

#include "polyglot/frontend/Source.h"

#ifndef _JC_polyglot_frontend_FileSource_H_
#define _JC_polyglot_frontend_FileSource_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_io_FileReader$object;
struct _jc_java_io_Reader$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_frontend_FileSource$sub_refs	_jc_polyglot_frontend_FileSource$sub_refs;
typedef struct _jc_polyglot_frontend_FileSource$sub_nonrefs	_jc_polyglot_frontend_FileSource$sub_nonrefs;
typedef struct _jc_polyglot_frontend_FileSource$refs	_jc_polyglot_frontend_FileSource$refs;
typedef struct _jc_polyglot_frontend_FileSource$nonrefs	_jc_polyglot_frontend_FileSource$nonrefs;
typedef struct _jc_polyglot_frontend_FileSource$object	_jc_polyglot_frontend_FileSource$object;

typedef const struct _jc_polyglot_frontend_FileSource$vmethods	_jc_polyglot_frontend_FileSource$vmethods;
typedef const struct _jc_polyglot_frontend_FileSource$vtable	_jc_polyglot_frontend_FileSource$vtable;
typedef const struct _jc_polyglot_frontend_FileSource$vtype	_jc_polyglot_frontend_FileSource$vtype;

// Constructors
extern void _jc_polyglot_frontend_FileSource$method$_init$538ee07130435a5e(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_java_io_File$object *) _JC_JCNI_ATTR;
extern void _jc_polyglot_frontend_FileSource$method$_init$c31b894660454d13(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_polyglot_frontend_FileSource$method$close$6aba8b329fddcd79(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *) _JC_JCNI_ATTR;
extern jboolean _jc_polyglot_frontend_FileSource$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_frontend_FileSource$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *) _JC_JCNI_ATTR;
extern struct _jc_java_io_Reader$object *_jc_polyglot_frontend_FileSource$method$open$bf04e002098c1544(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_frontend_FileSource$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_FileSource$method_info$close$6aba8b329fddcd79;
extern _jc_method _jc_polyglot_frontend_FileSource$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_frontend_FileSource$method_info$hashCode$53152098849316df;
extern _jc_method _jc_polyglot_frontend_FileSource$method_info$open$bf04e002098c1544;
extern _jc_method _jc_polyglot_frontend_FileSource$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_frontend_FileSource$vmethods {
	void	(*close$6aba8b329fddcd79)(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *) _JC_JCNI_ATTR;
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *) _JC_JCNI_ATTR;
	struct _jc_java_io_Reader$object	*(*open$bf04e002098c1544)(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_frontend_FileSource$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_frontend_FileSource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_Source$vmethods	polyglot_frontend_Source;
	_jc_polyglot_frontend_FileSource$vmethods	polyglot_frontend_FileSource;
};

// Vtype
struct _jc_polyglot_frontend_FileSource$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_FileSource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_FileSource$sub_refs {
	struct _jc_java_io_File$object	*file;
	struct _jc_java_io_FileReader$object	*reader;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_FileSource$refs {
    _jc_polyglot_frontend_FileSource$sub_refs	polyglot_frontend_FileSource;
    _jc_polyglot_frontend_Source$sub_refs	polyglot_frontend_Source;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_FileSource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_FileSource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_Source$sub_nonrefs	polyglot_frontend_Source;
    _jc_polyglot_frontend_FileSource$sub_nonrefs	polyglot_frontend_FileSource;
};

// Object instance structure
struct _jc_polyglot_frontend_FileSource$object {
	_jc_polyglot_frontend_FileSource$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_FileSource$vtype	*vtype;
	_jc_polyglot_frontend_FileSource$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_FileSource$vtype _jc_polyglot_frontend_FileSource$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_FileSource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_FileSource$class_object;

#endif	/* _JC_polyglot_frontend_FileSource_H_ */
